==> nitrite-1.0.1-sources.jar: org/dizitart/no2/objects/ObjectFilter.java <==
/*
 * Copyright 2017 Nitrite author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dizitart.no2.objects;

import org.dizitart.no2.Filter;
import org.dizitart.no2.NitriteId;
import org.dizitart.no2.internals.NitriteMapper;

/**
 * An interface to specify filtering criteria during {@link ObjectRepository}'s
 * find operations. When a filter is applied to a repository, based on the
 * criteria it returns a set of {@link NitriteId}s of matching records.
 *
 * Each filtering criteria is based on a field in the object. If the field is
 * indexed, the find operation takes the advantage of it and only scans the
 * index map for that field. But if the field is not indexed, it scans the
 * whole {@link ObjectRepository}.
 *
 * @since 1.0
 * @author Anindya Chatterjee.
 * @see org.dizitart.no2.Filter
 */
public interface ObjectFilter extends Filter {
    /**
     * Sets {@link NitriteMapper} to the filter.
     *
     * @param nitriteMapper the {@link NitriteMapper}.
     */
    void setNitriteMapper(NitriteMapper nitriteMapper);
}

==> nitrite-2.0.1-sources.jar: org/dizitart/no2/objects/ObjectFilter.java <==
/*
 * Copyright 2017 Nitrite author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dizitart.no2.objects;

import org.dizitart.no2.Filter;
import org.dizitart.no2.NitriteId;
import org.dizitart.no2.mapper.NitriteMapper;

/**
 * An interface to specify filtering criteria during {@link ObjectRepository}'s
 * find operations. When a filter is applied to a repository, based on the
 * criteria it returns a set of {@link NitriteId}s of matching records.
 *
 * Each filtering criteria is based on a field in the object. If the field is
 * indexed, the find operation takes the advantage of it and only scans the
 * index map for that field. But if the field is not indexed, it scans the
 * whole {@link ObjectRepository}.
 *
 * @since 1.0
 * @author Anindya Chatterjee.
 * @see org.dizitart.no2.Filter
 */
public interface ObjectFilter extends Filter {
    /**
     * Sets {@link NitriteMapper} to the filter.
     *
     * @param nitriteMapper the {@link NitriteMapper}.
     */
    void setNitriteMapper(NitriteMapper nitriteMapper);
}
